
*********
*Replication of Clark, Fordham, and Nordstrom. 2011. Preying on the Misfortune of Others.
*Journal of Politics
*contact: Dave Clark, dclark@binghamton.edu
*********

clear

use CFN_JOP_replication.dta

**Models 1 & 2
reghv Oweis_ouq Oweis_uoq unemp dempres  communist if oecd==0, var(cinc communist) nolog robust 
reghv Ocopdab_ouq Ocopdab_uoq unemp dempres  communist if oecd==0, var(cinc communist)  nolog robust 


**Models 3 & 4

*********
*llf for SUR het regression
*********

*This is a seemingly unrelated regression model with a heteroskedastic
*component.  As the model is parameterized gamma1 and gamma2 (the heteroskedastic 
*component) is forced to be positive.  This constraint can be removed by excluding
*the ln from gen double e and f.  Starting values are obtained from two separate
*regressions. 

*To replicate, simply run all code and models below.
*LLF from Franklin APSR 1991; Clark, Reed, & Nordstrom AJPS 2008

*drop _all
*clear
set matsize 450
ml clear
program drop _all
program define surhet
	version 9.1
	args lnf beta1 gamma1 beta2 gamma2 rho
        tempvar a b c d e f g
        quietly {
        gen double `a'=-.5*`gamma1'-.5*`gamma2'-.5*(ln(1-`rho'*`rho'))
        gen double `b'=1/2*(1/(1-`rho'*`rho'))
        gen double `c'=($ML_y1-`beta1')^2/exp(ln(`gamma1'))
        gen double `d'=($ML_y2-`beta2')^2/exp(ln(`gamma2'))
        gen double `e'=($ML_y1-`beta1')/exp(.5*ln(`gamma1'))
        gen double `f'=($ML_y2-`beta2')/exp(.5*ln(`gamma2'))
        gen double `g'=2*`rho'
        quietly replace `lnf'= `a'-`b'*(`c'-`g'*(`e'*`f')+`d') 
        }
end


#delimit ;
ml model lf surhet (Xbeta1:weiscoop_ouq= weiscoop_uoq unemp dempres communist)  (gamma1: cinc communist) 
(Xbeta2:Oweisconf_ouq= Oweisconf_uoq unemp dempres communist )  (gamma2: cinc communist) (rho:) if oecd==0,robust ;
ml search ;
ml maximize, difficult;
**COPDAB
#delimit ;
ml model lf surhet (Xbeta1:copdabcoop_ouq= copdabcoop_uoq unemp dempres  communist  )  (gamma1: cinc communist ) 
(Xbeta2:Ocopdabconf_ouq= Ocopdabconf_uoq unemp dempres communist )  (gamma2: cinc communist) (rho:) if oecd==0,robust ;
ml search ;
ml maximize, difficult;
